%global svnversion 2450

Name: skychart
Version: 3.8
Release: 1%{?dist}
Summary: Planetarium software for the advanced amateur astronomer

Group: Amusements/Graphics
License: GPLv2+
URL: http://www.ap-i.net/skychart/
Source0: %{name}-%{version}-%{svnversion}-src-nopatents.tar.bz2
# Skychart contains iridflare.exe
# Since it is pre-built code and the license is not clear
# we remove it from sources.
# Download upstream tarball and invoke this script
# while in tarballs directory:
# ./generate-tarball.sh 3.8-2450
Source1: generate-tarball.sh
Patch1: skychart-3.8-strip.patch
Patch2: skychart-wgetdata.patch

# no fpc and lazarus on s390(x) and armv7hl
# no lazarus on sparc(64)
ExcludeArch:    s390 s390x sparc sparc64 armv7hl

# Skychart fails to compile on ppc and ppc64
ExcludeArch:    ppc ppc64

BuildRequires: fpc >= 2.4.4
BuildRequires: lazarus >= 1.0.4
BuildRequires: ImageMagick desktop-file-utils dos2unix gtk2-devel
BuildRequires: prelink
Requires: xdg-utils tzdata xplanet

%description
This program enables you to draw sky charts, making use of the data in 16
catalogs of stars and nebulae. In addition the position of planets,
asteroids and comets are shown.

The purpose of this program is to prepare different sky maps for a
particular observation. A large number of parameters help you to choose
specifically or automatically which catalogs to use, the colour and the
dimension of stars and nebulae, the representation of planets, the display
of labels and coordinate grids, the superposition of pictures, the
condition of visibility and more. All these features make this celestial
atlas more complete than a conventional planetarium.

%package doc
Summary:        Documentation files for Skychart
Group:          Documentation
License:        CC-BY-SA or GFDL
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description doc
Documentation files from the official Skychart wiki provided
within the program as an offline copy.


%prep
%setup -q -n %{name}-%{version}-%{svnversion}-src

%patch1 -p1

# Disable wget for documentation and ephemeris data
%patch2 -p1

find skychart -type f -print0 |xargs -0 chmod 644

# Fix exotic EOL encodings
dos2unix -q -k tools/doc/html_doc/en/feature_class_fichiers/common.css
dos2unix -q -k tools/doc/html_doc/en/feature_class_fichiers/custom.css
dos2unix -q -k tools/doc/releasenotes*.txt

# Remove pre-compiled software quicksat.exe
rm -R --force tools/data/quicksat

%build
./configure lazarus=%{_libdir}/lazarus prefix=%{_prefix}

# We build these separately so that we can apply optflags
make %{_smp_mflags} arch_flags="%{optflags}" -C skychart/library/getdss
make %{_smp_mflags} arch_flags="%{optflags}" -C skychart/library/plan404
make %{_smp_mflags} arch_flags="%{optflags}" -C skychart/library/wcs

make # not concurrency-safe

%install
rm -rf %{buildroot}

# Install main program
make install PREFIX=%{buildroot}%{_prefix}

# Install catalogs, translations and data files
make install install_data PREFIX=%{buildroot}%{_prefix}

# Install wiki documentation
make install install_doc PREFIX=%{buildroot}%{_prefix}

# Fix multilib path
[ %{_lib} = lib ] || mv %{buildroot}%{_prefix}/{lib,%{_lib}}

# Fix debuginfo
chmod +x %{buildroot}%{_libdir}/*

# Menu entry
desktop-file-validate %{buildroot}%{_datadir}/applications/skychart.desktop


%files
%defattr(-,root,root,-)
%doc skychart/gpl.txt
%{_bindir}/*
%{_libdir}/*.so
%{_datadir}/applications/*
%{_datadir}/pixmaps/*
%{_datadir}/icons/*
%dir %{_datadir}/skychart
%{_datadir}/skychart/data
%{_datadir}/skychart/cat
%{_datadir}/skychart/doc/html_doc
%{_datadir}/skychart/doc/releasenotes*.txt
%{_datadir}/skychart/doc/varobs
%exclude /usr/share/doc/skychart/changelog
%exclude /usr/share/doc/skychart/copyright

%files doc
%defattr(-,root,root,-)
%doc %{_datadir}/skychart/doc/wiki_doc

%post
/sbin/ldconfig
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
/sbin/ldconfig
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%changelog
* Sat Mar 16 2013 Mattia Verga <mattia.verga@tiscali.it> - 3.8-1
- Update to 3.8
- Requires Lazarus >= 1.0.4

* Sun Mar 10 2013 Mattia Verga <mattia.verga@tiscali.it> - 3.7-0.3.2268svn
- Exclude armv7hl architecture

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7-0.2.2268svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Oct 06 2012 Mattia Verga <mattia.verga@tiscali.it> - 3.7-0.1.2268svn
- Update to 3.7 testing version

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.6-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Apr 20 2012 Mattia Verga <mattia.verga@tiscali.it> - 3.6-3
- Rebuild with lazarus 0.9.30.4 fix bug #799711
- Correct patch

* Sat Mar 17 2012 Mattia Verga <mattia.verga@tiscali.it> - 3.6-1
- Update to 3.6 version
- Modify sources to remove iridflar.exe
- Remove patches merged upstream
- Make sure fpc >= 2.4.4 to avoid execstack errors
- Add scriptlets for icon cache
- Make sure lazarus >= 0.9.30.4 to work with F17 and higher

* Sun Jan 22 2012 Mattia Verga <mattia.verga@tiscali.it> - 3.4-4
- Added wiki documentation as subpackage
- Fix old FSF address in license file
- Remove binary software quicksat.exe and IRIDFLAR.EXE
- Excluded ppc architecture, since lazarus < 0.9.30

* Sat Jan 21 2012 Mattia Verga <mattia.verga@tiscali.it> - 3.4-3
- Patch to make it compile with gcc 4.7

* Fri Jan 20 2012 Sergio Pascual <sergiopr@fedoraproject.org> - 3.4-2
- Added missing source tarball
- Renamed patches

* Thu Jan 19 2012 Sergio Pascual <sergiopr@fedoraproject.org> - 3.4-1
- New upstream source
- New source with ephemeris

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue May 03 2011 Dan Horák <dan[at]danny.cz> - 3.2-5
- no lazarus on s390(x)

* Thu Apr 28 2011 Sergio Pascual <sergiopr@fedoraproject.org> - 3.2-4
- Rebuilding with lazarus 0.9.30

* Wed Mar 09 2011 Sergio Pascual <sergiopr@fedoraproject.org> - 3.2-3
- Patch from upstream to make skychart work with lazarus 0.9.28

* Wed Feb 16 2011 Sergio Pascual <sergiopr@fedoraproject.org> - 3.2-2
- Missing patch added

* Sat Feb 12 2011 Sergio Pascual <sergiopr@fedoraproject.org> - 3.2-1
- New upstream source

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.1.6-5.20100724svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jan 13 2011 Sergio Pascual <sergiopr@fedoraproject.org> - 3.0.1.6-4.20100724svn
- Using d-f-validate instead od d-f-install (Fixes bz #662472)
- Changed RPM_BUILD_ROOT macro to lower case form

* Sat Jul 24 2010 Lubomir Rintel (Fedora Astronomy) <lkundrak@v3.sk> - 3.0.1.6-3.20100724svn
- Update to a later snapshot

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.1.6-2.20090408svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Apr 08 2009 Lubomir Rintel (Fedora Astronomy) <lkundrak@v3.sk> - 3.0.1.6-1.20090408svn
- Update to post latest beta
- Drop the unzip patch
- Upstream did the datadir and xdg-open chage as well, drop patches

* Wed Apr 08 2009 Lubomir Rintel (Fedora Astronomy) <lkundrak@v3.sk> - 3.0.1.5-6.20081026svn
- Enable GTK2 UI

* Fri Mar 27 2009 Lubomir Rintel (Fedora Astronomy) <lkundrak@v3.sk> - 3.0.1.5-5.20081026svn
- Fix desktop entry categories

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.1.5-4.20081026svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Dec 01 2008 Lubomir Rintel (Fedora Astronomy) <lkundrak@v3.sk> - 3.0.1.5-3.20081026svn
- Own /usr/share/skychart (#474037)

* Thu Nov 06 2008 Lubomir Rintel (Fedora Astronomy) <lkundrak@v3.sk> - 3.0.1.5-2.20081026svn
- Temporarily disable ppc64 build due to a compiler bug

* Wed Oct 29 2008 Lubomir Rintel (Fedora Astronomy) <lkundrak@v3.sk> - 3.0.1.5-1.20081026svn
- Rebase to later upstream, since we have more recent fpc and lazarus now

* Sun Oct 26 2008 Lubomir Rintel (Fedora Astronomy) <lkundrak@v3.sk> - 3.0.1.3-1.20071015svn
- Initial packaging attempt
